@@ -1,4 +1,3 @@
-from contextlib import suppress
 import boto3
 from datetime import datetime
 from .settings import settings
@@ -8,7 +7,7 @@ region = settings.AWS_REGION
 bucket_name = settings.S3_BUCKET_NAME
 dynamo_state_table_name = settings.DYNAMODB_STATE_TABLE_NAME
 
-with suppress(Exception):  # not gonna need this on local
+if settings.ENVIRONMENT == 'local':  # not gonna need this on local
     dynamodb = boto3.resource('dynamodb', region_name=region)
     s3 = boto3.resource('s3', region_name=region)
 
